@@ -59,6 +59,19 @@ def fix(files):
     rename_dirs(files)
 
 
+def start_tests():
+    files = ('no_changes', 'add_comments', 'change_comment', 'rename_fields', 'rename_class')
+    chdir('tests')
+    for file in files:
+        try:
+            file_before = open(file+'_before.java')
+            print('opened')
+        except Exception as e:
+            print(f'something was wrong with files {file}_before.java and {file}_after.java')
+            print(e)
+    pass
+
+
 class_interface_enum = ('class', 'interface', 'enum', '@interface')
 
 
