@@ -1,9 +1,9 @@
 import sys
 
 from .file import File
-from .formatter import get_files, get_files_rec, fix, validate
+from .formatter import get_files, get_files_rec, fix, validate, start_tests
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 
 
 def print_help():
@@ -16,6 +16,8 @@ AndrikBJavaCCF --fix -(p|d|f) /..
 AndrikBJavaCCF -f  -(p|d|f) /..
 AndrikBJavaCCF --help
 AndrikBJavaCCF -h
+AndrikBJavaCCF --test
+AndrikBJavaCCF -t
 where :
 -p - project
 -d - directory
@@ -32,6 +34,8 @@ def main():
     else:
         if sys.argv[1] in ('-h', '--help'):
             print_help()
+        elif sys.argv[1] in ('-t', '--test'):
+            start_tests()
         elif len(sys.argv) != 4:
             print("Error! Please, write arguments\n")
             print_help()
